Modules
Constants
- LATEST_
SUPPORTED_ TOOLCHAIN_ VERSION_ TAG - The latest version (github tag) of the toolchain that is supported by our build system.
- RUSTUP_
TOOLCHAIN_ NAME - SP1_
VERSION_ MESSAGE
Functions
- get_
target - get_
toolchain_ asset_ url - Find the toolchain asset for the given target in the GitHub releases API and return
its API download URL. Using the API URL (with
Accept: application/octet-stream) instead of the browser download URL ensures authentication works correctly, including for draft releases. - is_
supported_ target