Crate sp1_cli

Crate sp1_cli 

Modules

commands

Constants

LATEST_SUPPORTED_TOOLCHAIN_VERSION_TAG
The latest version (github tag) of the toolchain that is supported by our build system.
RUSTUP_TOOLCHAIN_NAME
SP1_VERSION_MESSAGE

Functions

get_target
get_toolchain_asset_url
Find the toolchain asset for the given target in the GitHub releases API and return its API download URL. Using the API URL (with Accept: application/octet-stream) instead of the browser download URL ensures authentication works correctly, including for draft releases.
is_supported_target